@@ -5,7 +5,6 @@ try:
     _not_ipython = False
 except ImportError:
     _not_ipython = True
-    pass
 from collections import defaultdict
 from collections.abc import Iterable
 from functools import partial
@@ -284,7 +283,7 @@ class Controls:
             step = slider.step
         else:
             raise NotImplementedError(
-                "Cannot save animation for slider of type %s".format(slider.__class__.__name__)
+                "Cannot save animation for slider of type {slider.__class__.__name__}"
             )
 
         N = int((max_ - min_) / step)
@@ -394,7 +393,7 @@ def gogogo_controls(
         if extra_controls is None:
             extra_controls = [ctrl_context]
         else:
-            extra_controls.append[ctrl_context]
+            extra_controls.append(ctrl_context)
 
     # Squash controls + extra_controls and make sure we have a unique controller object
 
